'use strict';

// We rely on a global jQuery instance here, so don't initialize the module if none is found
if (window.hasOwnProperty('$')) {
	var $likeContainer = $('#tx-sgnews-likes'),
		$likeButton = $likeContainer.find('.btn'),
		$numberOfLikes = $likeButton.find('.tx-sgnews-number-of-likes-value'),
		newsId = $likeContainer.data('uid');

	$likeButton.on('click', addLike);
	checkButtonStatus();

	/**
	 * Fires the Ajax-Call to add a new Like
	 * Won't do anything if the user already committed a like
	 */
	function addLike() {
		if (!window.localStorage.getItem('sg-news-like-' + newsId)) {
			$likeButton.addClass('tx-sgnews-loading');
			$.post('?eID=sgAjax&extensionName=SgNews&controller=Ajax\\Like&action=addLike&format=json', {
				parameters: { newsPid: newsId }
			}).then(function(data) {
				data = JSON.parse(data);
				$likeButton.removeClass('tx-sgnews-loading');
				if (data.success) {
					window.localStorage.setItem('sg-news-like-' + newsId, true);
					updateButton(true);
				}
			});
		}
	}

	/**
	 * Checks if the user already committed a like and updates the button accordingly
	 */
	function checkButtonStatus() {
		if (window.localStorage.getItem('sg-news-like-' + newsId)) {
			updateButton(false);
		}
	}

	/**
	 * Update the like-button status
	 *
	 * @param {bool} addedLike If set to true, the like-count will also be increased
	 */
	function updateButton(addedLike) {
		$likeButton.removeClass('btn-info').addClass('btn-success');
		$likeButton.find('.fa-star-o').removeClass('fa-star-o').addClass('fa-star');
		$likeButton.blur();
		if (addedLike) {
			var currentValue = parseInt($numberOfLikes.text());
			$numberOfLikes.text(currentValue + 1);
		}
	}

} else {
	console.warn('The sg_news like feature requires an instance of jQuery to be present!');
}
