/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

var SG = SG || {};

SG.ElementScrollBrowser = function() {
	this.initialize();
};

SG.ElementScrollBrowser.prototype = {
	/**
	 * @var int
	 */
	lastPage: 1,

	/**
	 * @var boolean
	 */
	lock: false,

	/**
	 * @var string|null
	 */
	url: null,

	/**
	 * @var string|null
	 */
	lastUrl: null,

	/**
	 * @var object
	 */
	loadIndicator: null,

	/**
	 * Initializes the class members and adds the necessary scroll events
	 *
	 * @return {void}
	 */
	initialize: function() {
		$('.tx-sgnews-pagebrowser').css('display', 'none');
		this.loadIndicator = $('.tx-sgnews-list').children(':last');
		if (!this.loadIndicator.length) {
			return;
		}

		this.url = $('.tx-pagebrowse-next a').attr('href');
		$(window).on('scroll', this.checkAndLoad.bind(this));

		// initial check
		this.checkAndLoad();
	},

	/**
	 * Checks and loads the next page if required
	 */
	checkAndLoad: function() {
		var recordLockedOrNotInPosition = this.lock || !this.checkPosition();
		var urlIsInvalid = typeof this.url === 'undefined' || this.url === this.lastUrl;
		if (recordLockedOrNotInPosition || urlIsInvalid) {
			return;
		}

		this.lock = true;
		$.ajax(
			{
				url: this.url,

				success: function(response) {
					var results = $(response).find('.tx-sgnews-list');
					results.each(function(index, result) {
						var $result = $(result);
						var children = $result.children();
						if (!children.length) {
							return;
						}

						var $resultList = $('.tx-sgnews-list-' + $result.data('record'));
						if (!$resultList.length) {
							$resultList = $('.tx-sgnews-list');
						}
						$resultList.append(children);

						this.loadIndicator = $resultList.children(':last');
					});

					this.lastUrl = this.url;
					this.url = $(response).find('.tx-pagebrowse-next a').attr('href');
					this.lock = false;
				}.bind(this)
			}
		);
	},

	/**
	 * Checks the current position of the scrollbar in relation to the position of the load indicator.
	 *
	 * @return boolean
	 */
	checkPosition: function() {
		var loadIndicatorPosition = this.loadIndicator.position(),
			windowScrollPosition = $(document).scrollTop();
		return (windowScrollPosition > (loadIndicatorPosition.top - 6000));
	}
};

$(document).ready(function() {
	(new SG.ElementScrollBrowser());
});
